@@ -159,12 +159,12 @@ def getInstalledVideo(prefix="/"):
     return [x[:-7] for x in listDirectory(x11Drivers) if x.endswith('_drv.so')]
 
 
-def getDistfilesVideo(prefix="/"):
+def getDistfilesVideo(self, prefix="/"):
     """Get video drivers from distfiles"""
-    if os.path.isdir('/var/db/repos/gentoo'):
+    if os.path.isdir(path.join(self.Get('cl_chroot_path'), 'var/db/repos/gentoo')):
         distFiles = path.join(prefix, "var/calculate/distfiles")
     else:
-        distFiles = path.join(prefix, "usr/portage/distfiles")
+        distFiles = path.join(prefix, "usr/portage/distfiles")    
     driver_map = {'ati': 'fglrx',
                   'amd': 'fglrx',
                   'radeon': 'fglrx',
